import { TemplateRef, ViewContainerRef } from '@angular/core';
declare type RxTemplateName = 'rxNext' | 'rxComplete' | 'rxError' | 'rxSuspense';
export interface TemplateManager<T> {
    updateViewContext(viewContextSlice: Partial<T>): void;
    addTemplateRef(name: RxTemplateName, templateRef: TemplateRef<T>): void;
    insertEmbeddedView(name: RxTemplateName): void;
    destroy(): void;
}
/**
 * TemplateManager
 *
 * @description
 * This function returns an object that holds the logic for managing templates of a `ViewContainerRef`.
 * It abstracts `EmbeddedView` creation, `insert` calls and `ViewContext` updates.
 * Internally it creates template references lazily by combining caching logic and the `ViewContainerRef#detach` method.
 * The `TemplateManager` lets you re-use templates and insert views on-demand, as well as update the view context
 * (e.g. when a new observable notification is sent).
 *
 * @param viewContainerRef reference to a top-level view container where passed templates will be attached
 * @param initialViewContext initial view context state
 */
export declare function createTemplateManager<T extends object>(viewContainerRef: ViewContainerRef, initialViewContext: T): TemplateManager<T>;
export {};
